/*******************************************************************************
*   Create Instrument
*******************************************************************************/

use  "$data/clean_full.dta", clear

* filter to correct dates and drop veterans
$limit_year
$limit_military

* filter to limit recidivism variables
qui sum book_date
replace recid365 = . if release >= (`r(max)' - 365)

replace recid_18mo = . if release >= (`r(max)' - (365*1.5))

replace recid_2yr = . if release >= (`r(max)' - (365*2))

* drop if no mh_rating
keep if inlist(mh_needs_rating, "Mild", "Moderate", "None", "Severe")

* Regression with no demographics and yes fixed effects
reghdfe $fs_out , a($time_fe ) residuals(resid)


* sum/count residuals by inmate
bysort inmate_id : egen count_resid_inmate = count(resid)
bysort inmate_id : egen sum_resid_inmate = sum(resid)
* sum/count residuals by clinician
bysort clin_id : egen sum_resid_clin = sum(resid)
bysort clin_id : egen count_resid_clin = count(resid)

* Create leave-out variable
gen z_$fs_out = (sum_resid_clin - sum_resid_inmate)/(count_resid_clin-count_resid_inmate)
lab var z_$fs_out "Z: Clinician's Leave-Out Mean Mental Health Score"
drop resid




/*******************************************************************************
*    Limit the analytic sample
*******************************************************************************/

* set the subsample
$limit_sample
gen adults = (age >= 26)

* Gen clinician fixed effects
	egen clin_id_year = group(clin_id year) // create clinician by year FE
	tab clin_id, gen(clinician_dd) // create clinician dummies

* Save data
save  "$data/${filelab}_final.dta", replace