********************************************************************************
*    Data Exploration
********************************************************************************
use "$data/${filelab}_final.dta", clear

**** Table 1 Summary Stats
	
	// this grabs the first outcome from the outcomes list so that we can tell
	//   the table where the header breaks without having to manually input it 
	//   every time.
	local first_outcome : word 1 of $outcomes
	// adds padding
	local sum_stat_list $tab_1_varlist
	foreach var of varlist `sum_stat_list' {
			local varlab : variable label `var'
			label variable `var' "\hspace{2em}`varlab'"
		}

	
	gen group_var = 1 if age < 26 & $fs_out == 0
	replace group_var = 2 if age < 26 & $fs_out == 1
	replace group_var = 3 if age >= 26 & $fs_out == 0
	replace group_var = 4 if age >= 26 & $fs_out == 1
	
	lab define group_lab 1 "None/Mild" 2 "Moderate/Severe" 3 "None/Mild" 4 "Moderate/Severe"
	lab val group_var `group_lab'

	forval i = 1/4 {
		qui sum $fs_out if group_var == `i'
		local n`i' : di %9.0fc `r(N)'
	}
	
	eststo clear
	estpost tabstat `sum_stat_list', ///
		by(group_var ) statistics(mean sd n) columns(statistics) nototal
	#delimit ;
	esttab using "${tables}/${filelab}_sum_stats.tex", nogaps noeqlines 
		replace cell(mean(fmt(3) label(Mean/Prop.))) nostar unstack nonote nomtitle nonumber noobs
		booktabs label  
		substitute("\_" "_")
		collabels(none) eqlabels("None/Mild" "Moderate/Severe" "None/Mild" "Moderate/Severe") 
		title("Descriptive Statistics by Initial Assessment of ${fs_lab}") 
		refcat(`first_outcome' `"\rule{0pt}{4ex}\textit{Outcomes}"' 
				white `"\rule{0pt}{4ex}\textit{Inmate Characteristics}"' 
				clin_male `"\rule{0pt}{4ex}\textit{Clinician Characteristics}"' , nolabel)
		prehead("\begin{table}[htbp]\centering" "\small" "\caption{@title}\label{tab:${filelab}_sumstats}"
				"\begin{center}" "\begin{threeparttable}" "\begin{tabular}{l*{@E}{c}}"
				"\toprule"
				"&\multicolumn{2}{c}{Transition Age}&\multicolumn{2}{c}{Adult} \\"
				"\cmidrule(lr){2-3} \cmidrule(lr){4-5}"
				)
		posthead("\midrule"
				"\rule{0pt}{4ex}\textit{Mental Health Needs}&            &            &            &            \\")
		prefoot("\midrule" 
				"Observations & `n1' & `n2'& `n3' & `n4'\\")
		postfoot("\bottomrule" "\end{tabular}" "\end{threeparttable}" "\end{center}"
				"\end{table}");
	#delimit cr
	foreach var of varlist `sum_stat_list' {
			local label : variable label `var'
			local label : subinstr local label "\hspace{2em}" "", all
			label variable `var' "`label'"
		}


		
**** Figures
twoway scatter tot_cases z_$fs_out, title("Distribution of Propensity to Assign ${fs_lab} by Total Cases")
graph export "$figures/${filelab}_propensity_by_tot_cases.png", as(png) replace


graph bar (mean) tcu_ever if year >= 2017, over( mh_court , lab(angle(45))) over(month) over(year) title("TCU Score > 0 by None/Mild vs. ${fs_lab}")
graph export "$figures/${filelab}_tcu_mh_court_monthly.png", as(png) replace

graph bar (mean) integral_care if year >= 2017, over( mh_court , lab(angle(45))) over(month) over(year) title("TCU Score > 0 by None/Mild vs. ${fs_lab}")
graph export "$figures/${filelab}_integral_mh_court_monthly.png", as(png) replace



if inlist("$filelab", "mis") {
	preserve
	use  "$data/clean_full.dta", clear
	forv s = 0/1 {
		qui mean tcu_ever integral_care if (mh_court == `s') & ((year == 2018 & month >=8) | year ==2019)
		estimates store mh`s'
	}

	coefplot mh0 mh1 ///
		  || , ///
				coeflabels(tcu_ever = "Ever Indicate Drug Use During Last 12 Months on the TCU Drug Screen in a Booking" integral_care = "Post-Release Treatment Program", wrap(50)) ///
				plotlabels("None/Mild Assessment (2018-2019)" "Moderate/Severe Assessment (2018-2019)") ///
				vertical legend(position(6)) ytitle("Proportion")
				
	graph export "$figures/full_tcu_ic_mh_court.png", as(png) replace
	restore
}

graph bar (mean) sa_hazard,  over( mh_court , lab(angle(45))) over(year) title("Suicide Attempt by None/Mild vs. ${fs_lab}") ytitle("Suicide Attempt (Proportion)")
graph export "$figures/${filelab}_sa_mh_court.png", as(png) replace

graph bar (median) los,  over( mh_court , lab(angle(45))) over(year) title("Length of stay by None/Mild vs. ${fs_lab}") ytitle("Median Length of Stay (Days)")
graph export "$figures/${filelab}_los_mh_court.png", as(png) replace

